Learn R Programming

DescToolsAddIns (version 1.8)

FileOpenDlg: Get the Path of a Data File to Be Opened

Description

Handling of pathnames is tedious in Windows because of the backslashes, that prevent simple pasting of a copied path into the source code. FileOpenDlg() displays the FileOpen-Dialog for picking a file interactively. When done, backslashes in the returned path will be replaced by simple slashes as used in R path definitions. The edited path is returned.

Usage

FileOpenDlg(fmt = NULL)

Arguments

fmt

the format, in which the filename parts should be returned. This can be defined quite flexible containing the elements path, filename and ext (file extension) enclosed by %. Default is path/filename.ext and coded as "%path%%filename%.%ext%". See examples for additional alternative definitions.

Value

character string containing the path (also present in the clipboard)

Details

There are 2 predefined formats that can be addressed with fmt = 1 resp. fmt = 2. 1 will return the path enclosed by a typical read.table(...) command, 2 will do the same with load(...).

See Also

file.choose

Examples

Run this code
# NOT RUN {
# choose a file
fn <- FileOpenDlg()
print(gettextf("You chose the file: %s ", fn))

# the path and filename can as well be nested in a command,
#   done here to build a read.table command that can be well inserted into the code:
FileOpenDlg(fmt="d.%fname% <- read.table(file = \"%path%\%fname%.%fxt%\",
  header = TRUE, sep = \";\", na.strings = c(\"NA\",\"NULL\"), strip.white = TRUE)")

# go to your editor and paste...
# }

Run the code above in your browser using DataLab