powered by
The function PlotPar() plots the typically used parameters and their values.
PlotPar()
PlotPar() PlotPch(col = NULL, bg = NULL, newwin = FALSE) PlotMar()
the default plotting color for PlotPch. Defaults to hred.
PlotPch
hred
The color to be used for the background of the plot symbols. Default is hecru.
hecru
logical, defining if a new graphic device should be used. Default is FALSE.
FALSE
PlotPch() will display the plot characters as defined by pch in all plots in a dialog.
PlotPch()
pch
PlotMar() plots the margins.
PlotMar()
par, colors
par
colors
# NOT RUN { PlotPar() PlotPch() # }
Run the code above in your browser using DataLab