powered by
Use RStudio's manipulator to explore a data.frame by dynamically creating xy-scatterplots, boxplots and others. Numerical descriptions can as well be produced on the fly.
Xplore(x)
the data.frame to be explored.
Andri Signorell <[email protected]>
This function helps to get rid of the afterwards superfluous R-code created while exploring a dataset.
if (FALSE) { Xplore(d.pizza) }
Run the code above in your browser using DataLab